@@ -1,5 +1,5 @@
 package Bio::Roary::External::Cdhit;
-$Bio::Roary::External::Cdhit::VERSION = '3.3.3';
+$Bio::Roary::External::Cdhit::VERSION = '3.3.4';
 # ABSTRACT: Wrapper to run cd-hit
 
 
@@ -19,9 +19,9 @@ has '_description_length'          => ( is => 'ro', isa => 'Int',  default  => 2
 has '_logging'                     => ( is => 'ro', isa => 'Str',  default  => '> /dev/null 2>&1' );
 
 # Overload Role
-has '_memory_required_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build_memory_in_mb' );
 
-sub _build__memory_required_in_mb
+sub _build_memory_in_mb
 {
   my ($self) = @_;
   my $filename = $self->input_file;
@@ -42,7 +42,7 @@ sub _build__memory_required_in_mb
 sub _build__max_available_memory_in_mb
 {
   my ($self) = @_;
-  my $memory_to_cdhit = int($self->_memory_required_in_mb *0.9);
+  my $memory_to_cdhit = int($self->memory_in_mb *0.9);
   return $memory_to_cdhit;
 }
 
@@ -75,7 +75,7 @@ sub run {
 	
     push(@commands_to_run, $self->_command_to_run() );
     $self->logger->info( "Running command: " . $self->_command_to_run() );
-    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->_memory_required_in_mb, queue => $self->_queue, cpus => $self->cpus );
+    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->memory_in_mb, queue => $self->_queue, cpus => $self->cpus );
     $job_runner_obj->run();
     
     1;
@@ -98,7 +98,7 @@ Bio::Roary::External::Cdhit - Wrapper to run cd-hit
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
