@@ -1,5 +1,5 @@
 package Bio::Roary::External::GeneAlignmentFromNucleotides;
-$Bio::Roary::External::GeneAlignmentFromNucleotides::VERSION = '3.3.3';
+$Bio::Roary::External::GeneAlignmentFromNucleotides::VERSION = '3.3.4';
 # ABSTRACT: Take in multi-FASTA files of nucleotides and align each file with PRANK or MAFFT
 
 
@@ -15,16 +15,17 @@ has 'dont_delete_files'           => ( is => 'rw', isa => 'Bool',     default  =
 has 'num_input_files'             => ( is => 'ro', isa => 'Int',      required => 1);
 
 # Overload Role
-has '_memory_required_in_mb' => ( is => 'ro', isa => 'Int', lazy     => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb' => ( is => 'rw', isa => 'Int', lazy     => 1, builder => '_build_memory_in_mb' );
 has '_min_memory_in_mb'      => ( is => 'ro', isa => 'Int', default => 500 );
 has '_max_memory_in_mb'      => ( is => 'ro', isa => 'Int', default => 60000 );
 has '_queue'                 => ( is => 'rw', isa => 'Str', default  => 'normal' );
 has '_files_per_chunk'       => ( is => 'ro', isa => 'Int', default  => 10 );
 has '_core_alignment_cmd'    => ( is => 'rw', isa => 'Str', lazy_build => 1 );
+has '_dependancy_memory_in_mb'  => ( is => 'ro', isa => 'Int', default => 10000 );
 
 
 
-sub _build__memory_required_in_mb {
+sub _build_memory_in_mb {
     my ($self)          = @_;
 
     my $largest_file_size = 1;
@@ -90,13 +91,14 @@ sub run {
 
     my $job_runner_obj = $self->_job_runner_class->new(
         commands_to_run => \@commands_to_run,
-        memory_in_mb    => $self->_memory_required_in_mb,
+        memory_in_mb    => $self->memory_in_mb,
         queue           => $self->_queue,
         dont_wait       => 1,
         cpus            => $self->cpus 
     );
     $job_runner_obj->run();
     
+	$job_runner_obj->memory_in_mb($self->_dependancy_memory_in_mb);
 	$self->logger->info( "Running command: " . $self->_core_alignment_cmd() );
     $job_runner_obj->submit_dependancy_job($self->_core_alignment_cmd);
     1;
@@ -118,7 +120,7 @@ Bio::Roary::External::GeneAlignmentFromNucleotides - Take in multi-FASTA files o
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
