@@ -1,5 +1,5 @@
 package Bio::Roary::External::IterativeCdhit;
-$Bio::Roary::External::IterativeCdhit::VERSION = '3.3.3';
+$Bio::Roary::External::IterativeCdhit::VERSION = '3.3.4';
 # ABSTRACT: Iteratively run CDhit
 
 
@@ -13,9 +13,9 @@ has 'output_filtered_clustered_fasta' => ( is => 'ro', isa => 'Str', required =>
 has 'exec'                            => ( is => 'ro', isa => 'Str', default  => 'iterative_cdhit' );
 
 # Overload Role
-has '_memory_required_in_mb' => ( is => 'ro', isa => 'Int', lazy => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb' => ( is => 'ro', isa => 'Int', lazy => 1, builder => '_build_memory_in_mb' );
 
-sub _build__memory_required_in_mb {
+sub _build_memory_in_mb {
     my ($self)          = @_;
     my $filename        = $self->output_combined_filename;
     my $memory_required = 2000;
@@ -35,7 +35,7 @@ sub _build__memory_required_in_mb {
 
 sub _build__max_available_memory_in_mb {
     my ($self) = @_;
-    my $memory_to_cdhit = int( $self->_memory_required_in_mb * 0.9 );
+    my $memory_to_cdhit = int( $self->memory_in_mb * 0.9 );
     return $memory_to_cdhit;
 }
 
@@ -59,7 +59,7 @@ sub run {
 	
     my $job_runner_obj = $self->_job_runner_class->new(
         commands_to_run => \@commands_to_run,
-        memory_in_mb    => $self->_memory_required_in_mb,
+        memory_in_mb    => $self->memory_in_mb,
         queue           => $self->_queue,
         cpus            => $self->cpus 
     );
@@ -85,7 +85,7 @@ Bio::Roary::External::IterativeCdhit - Iteratively run CDhit
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
