@@ -1,5 +1,5 @@
 package Bio::Roary::External::Makeblastdb;
-$Bio::Roary::External::Makeblastdb::VERSION = '3.3.3';
+$Bio::Roary::External::Makeblastdb::VERSION = '3.3.4';
 # ABSTRACT: Wrapper around NCBIs makeblastdb command
 
 
@@ -16,7 +16,7 @@ has '_logfile'           => ( is => 'ro', isa => 'Str', default  => '/dev/null'
 has 'output_database'    => ( is => 'ro', isa => 'Str', lazy     => 1, builder => '_build_output_database' );
 
 # Overload Role
-has '_memory_required_in_mb'  => ( is => 'ro', isa => 'Int', default => 4000);
+has 'memory_in_mb'  => ( is => 'ro', isa => 'Int', default => 4000);
 
 sub _build_output_database {
     my ($self) = @_;
@@ -43,7 +43,7 @@ sub run {
   my @commands_to_run;
   push(@commands_to_run, $self->_command_to_run );
   $self->logger->info( "Running command: " . $self->_command_to_run() );
-  my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->_memory_required_in_mb, queue => $self->_queue, cpus  => $self->cpus  );
+  my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->memory_in_mb, queue => $self->_queue, cpus  => $self->cpus  );
   $job_runner_obj->run();
   
   1;
@@ -65,7 +65,7 @@ Bio::Roary::External::Makeblastdb - Wrapper around NCBIs makeblastdb command
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
