@@ -1,5 +1,5 @@
 package Bio::Roary::External::Mcl;
-$Bio::Roary::External::Mcl::VERSION = '3.3.3';
+$Bio::Roary::External::Mcl::VERSION = '3.3.4';
 # ABSTRACT: Wrapper around MCL which takes in blast results and outputs clustered results
 
 
@@ -18,9 +18,9 @@ has '_score'     => ( is => 'ro', isa => 'Str', default  => 'r' );
 has '_inflation_value' => ( is => 'ro', isa => 'Num', default => 1.5 );
 has '_logging'         => ( is => 'ro', isa => 'Str', default  => '> /dev/null 2>&1' );
 
-has '_memory_required_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build_memory_in_mb' );
 
-sub _build__memory_required_in_mb
+sub _build_memory_in_mb
 {
   my ($self) = @_;
   # Todo: implement this equation for memory estimation if this hardcoded value proves too unstable.
@@ -79,7 +79,7 @@ sub run {
     my @commands_to_run;
     push(@commands_to_run, $self->_command_to_run );
     $self->logger->info( "Running command: " . $self->_command_to_run() );
-    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->_memory_required_in_mb, queue => $self->_queue,        cpus            => $self->cpus  );
+    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->memory_in_mb, queue => $self->_queue,        cpus            => $self->cpus  );
     $job_runner_obj->run();
     
     1;
@@ -101,7 +101,7 @@ Bio::Roary::External::Mcl - Wrapper around MCL which takes in blast results and
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
