@@ -1,5 +1,5 @@
 package Bio::Roary::External::Prank;
-$Bio::Roary::External::Prank::VERSION = '3.3.3';
+$Bio::Roary::External::Prank::VERSION = '3.3.4';
 # ABSTRACT: Wrapper to run prank
 
 
@@ -12,9 +12,9 @@ has 'output_filename' => ( is => 'ro', isa => 'Str', default  => 'output' );
 has 'exec'            => ( is => 'ro', isa => 'Str', default  => 'prank' );
 
 # Overload Role
-has '_memory_required_in_mb' => ( is => 'ro', isa => 'Int', lazy => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb' => ( is => 'ro', isa => 'Int', lazy => 1, builder => '_build_memory_in_mb' );
 
-sub _build__memory_required_in_mb {
+sub _build_memory_in_mb {
     my ($self) = @_;
     my $memory_required = 2000;
     return $memory_required;
@@ -50,7 +50,7 @@ sub run {
 
     my $job_runner_obj = $self->_job_runner_class->new(
         commands_to_run => \@commands_to_run,
-        memory_in_mb    => $self->_memory_required_in_mb,
+        memory_in_mb    => $self->memory_in_mb,
         queue           => $self->_queue,
         cpus            => $self->cpus
     );
@@ -76,7 +76,7 @@ Bio::Roary::External::Prank - Wrapper to run prank
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
