@@ -1,5 +1,5 @@
 package Bio::Roary::ParallelAllAgainstAllBlast;
-$Bio::Roary::ParallelAllAgainstAllBlast::VERSION = '3.3.3';
+$Bio::Roary::ParallelAllAgainstAllBlast::VERSION = '3.3.4';
 # ABSTRACT: Run all against all blast in parallel
 
 
@@ -29,7 +29,7 @@ has '_working_directory' =>
   ( is => 'ro', isa => 'File::Temp::Dir', default => sub { File::Temp->newdir( DIR => getcwd, CLEANUP => 1 ); } );
 has '_working_directory_name' => ( is => 'ro', isa => 'Str', lazy => 1, builder => '_build__working_directory_name' );
 
-has '_memory_required_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build__memory_required_in_mb' );
+has 'memory_in_mb'  => ( is => 'ro', isa => 'Int',  lazy => 1, builder => '_build_memory_in_mb' );
 
 
 sub BUILD {
@@ -82,7 +82,7 @@ sub _combine_blast_results {
     return 1;
 }
 
-sub _build__memory_required_in_mb
+sub _build_memory_in_mb
 {
   my ($self) = @_;
   my $filename = $self->fasta_file;
@@ -119,7 +119,7 @@ sub run {
         push( @commands_to_run,       $blast_database->_command_to_run() );
 		$self->logger->info( "Running command: " . $blast_database->_command_to_run() );
     }
-    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->_memory_required_in_mb, queue => $self->_queue, cpus  => $self->cpus );
+    my $job_runner_obj = $self->_job_runner_class->new( commands_to_run => \@commands_to_run, memory_in_mb => $self->memory_in_mb, queue => $self->_queue, cpus  => $self->cpus );
     $job_runner_obj->run();
 	$self->logger->info( "Combining blast results" );
     $self->_combine_blast_results(\@expected_output_files);
@@ -143,7 +143,7 @@ Bio::Roary::ParallelAllAgainstAllBlast - Run all against all blast in parallel
 
 =head1 VERSION
 
-version 3.3.3
+version 3.3.4
 
 =head1 SYNOPSIS
 
